@@ -1,8 +1,13 @@
+import importlib
 import typing
 
-from marshmallow import class_registry, fields, missing
-from marshmallow.exceptions import StringNotCollectionError, ValidationError
-from marshmallow.fields import Field
+from marshmallow import class_registry, fields, missing, post_dump
+from marshmallow.exceptions import (
+    RegistryError,
+    StringNotCollectionError,
+    ValidationError,
+)
+from marshmallow.fields import Field, Nested
 from marshmallow.utils import RAISE, is_collection
 from marshmallow.utils import missing as missing_
 
@@ -23,6 +28,34 @@ class OptionalList(fields.List):
         return super()._deserialize(value, attr, data, **kwargs)
 
 
+class MappingField(Field):
+    def _serialize(self, nested_obj, attr, obj):
+        result = {}
+        values = obj.get(attr) or {}
+        for key, value in values.items():
+            result["var.%s" % key] = value
+        return result
+
+
+class RemoveEmptyValuesMixin:
+    @post_dump
+    def remove_empty_values(self, data, **kwargs):
+        """Remove the key, value pairs for which the value is None.
+
+        This doesn't work if allow_none is set. And in the future we might also
+        want to remove values which are already the default to minimise the
+        params.
+
+        """
+        result = {}
+        for k, v in data.items():
+            if isinstance(v, list):
+                result[k] = [x for x in v if x is not None]
+            elif v is not None:
+                result[k] = v
+        return result
+
+
 class RegexField(Field):
     def _serialize(self, nested_obj, attr, obj):
         result = {}
@@ -47,15 +80,29 @@ class RegexField(Field):
         return data
 
     def preprocess(self, data):
-        new: typing.Dict[str, typing.Any] = {self.name: {}}
+        name = str(self.name)
+        new: typing.Dict[str, typing.Any] = {name: {}}
         for k, v in data.items():
             if self.metadata["pattern"].match(k):
-                new[self.name][k] = v
+                new[name][k] = v
             else:
                 new[k] = v
         return new
 
 
+class LazyNestedField(Nested):
+    @property
+    def schema(self):
+        try:
+            return super().schema
+        except RegistryError:
+            if isinstance(self.nested, str):
+                names = self.nested.rsplit(".", 1)
+                importlib.import_module(names[0])
+                return super().schema
+            raise
+
+
 class Discriminator(Field):
     default_error_messages = {"type": "Invalid type."}
 
@@ -85,6 +132,12 @@ class Discriminator(Field):
     def get_schema(self, name):
         context = getattr(self.parent, "context", {})
         schema_class = class_registry.get_class(name)
+
+        # Class registry can return a list if multiple classes with the same
+        # name are registered. We shouldn't do that so lets assert it.
+        # and make mypy happy :-)
+        assert not isinstance(schema_class, list)
+
         schema = schema_class(
             many=self.many,
             only=self.only,
@@ -199,7 +252,8 @@ def _concurrent_retry(num):
                         raise
 
                     if exc.response.status_code == 409:
-                        data["version"] = exc.response.errors[0].current_version
+                        if exc.response.errors:
+                            data["version"] = exc.response.errors[0].current_version
                     else:
                         raise
                     num -= 1
